# eric7.Plugins.WizardPlugins.EricMessageBoxWizard.EricMessageBoxWizardDialog

Module implementing the eric message box wizard dialog.

### Global Attributes

None

### Classes

EricMessageBoxWizardDialog | Class implementing the eric message box wizard dialog.

### Functions

None

## EricMessageBoxWizardDialog

Class implementing the eric message box wizard dialog.

It displays a dialog for entering the parameters for the EricMessageBox code generator.

### Derived from

QDialog, Ui_EricMessageBoxWizardDialog

### Class Attributes

None

### Class Methods

None

### Methods

EricMessageBoxWizardDialog | Constructor
__enabledGroups | Private method to enable/disable some group boxes.
__getDefaultButtonCode | Private method to generate the button code for the default button.
__getStandardButtonCode | Private method to generate the button code for the standard buttons.
getCode | Public method to get the source code.
on_bTest_clicked | Private method to test the selected options.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
on_rAboutQt_toggled | Private slot to handle the toggled signal of the rAboutQt radio button.
on_rAbout_toggled | Private slot to handle the toggled signal of the rAbout radio button.
on_rCritical_toggled | Private slot to handle the toggled signal of the rCritical radio button.
on_rInformation_toggled | Private slot to handle the toggled signal of the rInformation radio button.
on_rOkToClearData_toggled | Private slot to handle the toggled signal of the rOkToClearData radio button.
on_rQuestion_toggled | Private slot to handle the toggled signal of the rQuestion radio button.
on_rRetryAbort_toggled | Private slot to handle the toggled signal of the rRetryAbort radio button.
on_rStandard_toggled | Private slot to handle the toggled signal of the rStandard radio button.
on_rWarning_toggled | Private slot to handle the toggled signal of the rWarning radio button.
on_rYesNo_toggled | Private slot to handle the toggled signal of the rYesNo radio button.

### Static Methods

None

#### EricMessageBoxWizardDialog (Constructor)

EricMessageBoxWizardDialog(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### EricMessageBoxWizardDialog.__enabledGroups

__enabledGroups()

Private method to enable/disable some group boxes.

#### EricMessageBoxWizardDialog.__getDefaultButtonCode

__getDefaultButtonCode(istring)

Private method to generate the button code for the default button.

istring (str)
  indentation string

Return:
  the button code

Return Type:
  str

#### EricMessageBoxWizardDialog.__getStandardButtonCode

__getStandardButtonCode(istring, withIntro=True)

Private method to generate the button code for the standard buttons.

istring (str)
  indentation string
withIntro (bool)
  flag indicating to generate a first line with introductory text

Return:
  the button code

Return Type:
  str

#### EricMessageBoxWizardDialog.getCode

getCode(indLevel, indString)

Public method to get the source code.

indLevel (int)
  indentation level
indString (str)
  string used for indentation (space or tab)

Return:
  generated code

Return Type:
  str

#### EricMessageBoxWizardDialog.on_bTest_clicked

on_bTest_clicked()

Private method to test the selected options.

#### EricMessageBoxWizardDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button (QAbstractButton)
  button that was clicked

#### EricMessageBoxWizardDialog.on_rAboutQt_toggled

on_rAboutQt_toggled(_on)

Private slot to handle the toggled signal of the rAboutQt radio button.

_on (bool)
  toggle state (unused)

#### EricMessageBoxWizardDialog.on_rAbout_toggled

on_rAbout_toggled(_on)

Private slot to handle the toggled signal of the rAbout radio button.

_on (bool)
  toggle state (unused)

#### EricMessageBoxWizardDialog.on_rCritical_toggled

on_rCritical_toggled(_on)

Private slot to handle the toggled signal of the rCritical radio button.

_on (bool)
  toggle state (unused)

#### EricMessageBoxWizardDialog.on_rInformation_toggled

on_rInformation_toggled(_on)

Private slot to handle the toggled signal of the rInformation radio button.

_on (bool)
  toggle state (unused)

#### EricMessageBoxWizardDialog.on_rOkToClearData_toggled

on_rOkToClearData_toggled(_on)

Private slot to handle the toggled signal of the rOkToClearData radio button.

_on (bool)
  toggle state (unused)

#### EricMessageBoxWizardDialog.on_rQuestion_toggled

on_rQuestion_toggled(_on)

Private slot to handle the toggled signal of the rQuestion radio button.

_on (bool)
  toggle state (unused)

#### EricMessageBoxWizardDialog.on_rRetryAbort_toggled

on_rRetryAbort_toggled(_on)

Private slot to handle the toggled signal of the rRetryAbort radio button.

_on (bool)
  toggle state (unused)

#### EricMessageBoxWizardDialog.on_rStandard_toggled

on_rStandard_toggled(_on)

Private slot to handle the toggled signal of the rStandard radio button.

_on (bool)
  toggle state (unused)

#### EricMessageBoxWizardDialog.on_rWarning_toggled

on_rWarning_toggled(_on)

Private slot to handle the toggled signal of the rWarning radio button.

_on (bool)
  toggle state (unused)

#### EricMessageBoxWizardDialog.on_rYesNo_toggled

on_rYesNo_toggled(_on)

Private slot to handle the toggled signal of the rYesNo radio button.

_on (bool)
  toggle state (unused)

Up